@@ -197,7 +197,7 @@ apa.reg.boot.table<-function(...,filename=NA, table.number=NA, number.samples =
 
      tbl_console <- list(table_number = table_number,
                          table_title = table_title,
-                         table_body = table_body,
+                         table_body = as.data.frame(table_body),
                          table_note = table_note,
                          table_block_results = table_block_results)
 
@@ -352,7 +352,7 @@ apa_single_boot_block<-function(cur_blk,is_random_predictors, K, prop_var_conf_l
 
      #semi-partial correlation squared
      reg_table_lower   <- dplyr::mutate(reg_table_lower, sr2=(t*t)*(1-R2)/df2, LLsr2=-999,ULsr2=-999)
-     number_predictors <- length(reg_table_lower[,1])
+     number_predictors <- dim(reg_table_lower[,1])[1]
      # if (number_predictors>1) {
      #      #use delta R2 process for CI
      #      for (i in 1:number_predictors) {
@@ -387,6 +387,7 @@ apa_single_boot_block<-function(cur_blk,is_random_predictors, K, prop_var_conf_l
 
      #beta
      if (calculate_beta==TRUE) {
+          reg_table_lower   <- dplyr::mutate(reg_table_lower, beta = - 999, LLbeta = -999, ULbeta = -999)
           for (i in 1:number_predictors) {
                p_name  <- reg_table_lower$predictor[i]
                b       <- reg_table_lower$b[i]
